@@ -49,13 +49,17 @@ unset SPLASHPNG         || true
 unset OMIT_MANUAL	 || true
 unset OMIT_RELEASE_NOTES || true
 unset OMIT_DOC_TOOLS     || true
+unset MAX_PKG_SIZE       || true
 
 # The debian-cd dir
 # Where I am (hoping I'm in the debian-cd dir)
 export BASEDIR=`pwd`
 
-# Building lenny cd set ...
-export CODENAME=lenny
+# Name of the distribution for the image filename (Defaults to 'debian')
+# export CDNAME=debian
+
+# Building squeeze cd set ...
+export CODENAME=squeeze
 
 # By default use Debian installer packages from $CODENAME
 if [ -z "$DI_CODENAME" ]; then
@@ -69,7 +73,7 @@ fi
 #export DI_WWW_HOME=default
 
 # Version number, "2.2 r0", "2.2 r1" etc.
-export DEBVERSION="5.0"
+export DEBVERSION="6.0"
 
 # Official or non-official set.
 # NOTE: THE "OFFICIAL" DESIGNATION IS ONLY ALLOWED FOR IMAGES AVAILABLE
@@ -166,6 +170,12 @@ export ISOLINUX=1
 # uncomment this to if you want to see more of what the Makefile is doing
 #export VERBOSE_MAKE=1
 
+# The maximum size allowed for an individual package, in bytes; if
+# larger than this, it will be excluded (and all dependents, of
+# course). We'll create a README.excluded in the root of CD1 listing
+# them too
+export MAX_PKG_SIZE=600000000
+
 # uncoment this to make build_all.sh try to build a simple CD image if
 # the proper official CD run does not work
 ATTEMPT_FALLBACK=yes
@@ -189,6 +199,9 @@ export DISKTYPE=CD
 # included. See tasks/README.tasksel for further info.
 export TASK_LANGLIST=tasksel_d-i.languages
 
+# Extra variants to enable. See docs/README.variants for more information.
+export VARIANTS=
+
 # We don't want certain packages to take up space on CD1...
 #export EXCLUDE1=exclude
 # ...but they are okay for other CDs (UNEXCLUDEx == may be included
@@ -217,7 +230,7 @@ export ARCHIVE_EXTRACTED_SOURCES="http://cdimage.debian.org/cdimage/cd-sources/"
 # Produce iso/jigdo files: specify how many iso/jigdo files should be
 # produced in your set. If not set or when the value is "ALL" they will
 # be created for all images. One of the variables can be set to zero if
-# either iso or jigdo files are not wanted, but not both.
+# either iso or jigdo files are not wanted.
 # Replaces the old "DOJIGDO" setting with something much more flexible.
 #export MAXISOS=0
 #export MAXJIGDOS=0
@@ -320,7 +333,8 @@ done
 # Default desktop (currently only used by win32-loader)
 #export DESKTOP=kde
 
-# If set, limits the number of binary CDs to produce.
+# If set, limits the number of images to produce. The maximum
+# value of MAXISOS and MAXJIGDOS are limited to this setting.
 #export MAXCDS=1
 
 # If set, overrides the boot picture used.
