@@ -213,7 +213,7 @@ while (defined (my $pkg = <INLIST>)) {
         # lists intersect and we should re-include some packages
         if (scalar @unexclude_packages && scalar @excluded_package_list) {
             foreach my $reinclude_pkg (@excluded_package_list) {
-                my ($arch, $component, $pkgname) = split /:/, $reinclude_pkg;
+                my ($arch, $component, $pkgname, $pkgsize) = split /:/, $reinclude_pkg;
                 foreach my $entry (@unexclude_packages) {
                     if (($pkgname =~ /^\Q$entry\E$/m)) {
                         print LOG "Re-including $reinclude_pkg due to match on \"\^$entry\$\"\n";
@@ -316,7 +316,7 @@ sub load_packages_cache {
 
     while (defined (my $pkg = <INLIST>)) {
         chomp $pkg;
-        my ($junk, $component, $pkgname) = split /:/, $pkg;
+        my ($junk, $component, $pkgname, $pkgsize) = split /:/, $pkg;
         push @pkglist, $pkgname;
     }
     close INLIST;
@@ -347,7 +347,7 @@ sub load_packages_cache {
 
 sub should_start_extra_nonfree {
     my $pkg = shift;
-    my ($arch, $component, $pkgname) = split /:/, $pkg;
+    my ($arch, $component, $pkgname, $pkgsize) = split /:/, $pkg;
 
 	if ( ($component eq "non-free") && $extranonfree) {
 		$extranonfree = 0; # Flag that we don't need to start new next time!
@@ -359,7 +359,7 @@ sub should_start_extra_nonfree {
 
 sub should_exclude_package {
     my $pkg = shift;
-    my ($arch, $component, $pkgname) = split /:/, $pkg;
+    my ($arch, $component, $pkgname, $pkgsize) = split /:/, $pkg;
     my $should_exclude = 0;
 
     foreach my $entry (@exclude_packages) {
@@ -392,6 +392,8 @@ sub check_base_installable {
 	my (%on_disc, %exclude);
 	my $packages_file = "$cddir/dists/$codename/main/binary-$arch/Packages";
 	my $p;
+	my $db_error = 0;
+	my $error_string = "";
 
 	open (PLIST, $packages_file)
 		|| die "Can't open Packages file $packages_file : $!\n";
@@ -423,19 +425,30 @@ sub check_base_installable {
 	open (DLIST, "debootstrap --arch $arch --print-debs $codename $tdir/debootstrap_tmp file:$mirror $debootstrap_script 2>/dev/null | tr ' ' '\n' |")
 		 || die "Can't fork debootstrap : $!\n";
 	while (defined($p = <DLIST>)) {
+        if ($p =~ m/^E:/) {
+            $db_error = 1;
+        }
 		chomp $p;
-		if (length $p > 1) {
-			if (!defined($on_disc{$p})) {
-				if (defined($exclude{$p})) {
-					print LOG "Missing debootstrap-required $p but included in $ENV{'BASE_EXCLUDE'}\n";
-				} else {
-					$ok++;
-					print LOG "Missing debootstrap-required $p\n";
-				}
-			}
-		}
-	}
-	close DLIST;
+        if ($db_error) {
+            $error_string = "$error_string $p";
+        } else {
+            if (length $p > 1) {
+                if (!defined($on_disc{$p})) {
+                    if (defined($exclude{$p})) {
+                        print LOG "Missing debootstrap-required $p but included in $ENV{'BASE_EXCLUDE'}\n";
+                    } else {
+                        $ok++;
+                        print LOG "Missing debootstrap-required $p\n";
+                    }
+                }
+            }
+        }
+    }
+    close DLIST;
+    if ($db_error) {
+        print LOG "Debootstrap reported error: $error_string\n";
+        die "Debootstrap reported error: $error_string\n";
+    }
 	system("rm -rf $tdir/debootstrap_tmp");
 	return $ok;
 }
@@ -991,7 +1004,7 @@ sub add_packages {
     }
 
     my $pkg = shift;
-	my ($arch, $component, $pkgname) = split /:/, $pkg;
+	my ($arch, $component, $pkgname, $pkgsize) = split /:/, $pkg;
 
     if ("$arch" eq "" or "$pkgname" eq "" or "$pkgname" eq "") {
         die "inconsistent data passed to add_packages: $pkg\n";
